/*
 * @package   admintools
 * @copyright Copyright (c)2010-2021 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

CREATE TABLE `#__admintools_adminiplist`
(
    `id`          bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `ip`          varchar(255) DEFAULT NULL,
    `description` varchar(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_badwords`
(
    `id`   bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `word` varchar(255) DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY (`word`(100))
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_customperms`
(
    `id`    bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `path`  varchar(255)        NOT NULL,
    `perms` varchar(4) DEFAULT '0644',
    PRIMARY KEY (`id`),
    KEY `#__admintools_customperms_path` (`path`(100))
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_filescache`
(
    `id`       bigint(20)    NOT NULL AUTO_INCREMENT,
    `path`     varchar(2048) NOT NULL,
    `filedate` int(11)       NOT NULL DEFAULT '0',
    `filesize` int(11)       NOT NULL DEFAULT '0',
    `data`     blob,
    `checksum` varchar(32)   NOT NULL DEFAULT '',
    PRIMARY KEY (`admintools_filescache_id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_ipautoban`
(
    `ip`     varchar(255) NOT NULL,
    `reason` varchar(255) DEFAULT 'other',
    `until`  datetime     DEFAULT NULL,
    PRIMARY KEY (`ip`(100))
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_ipblock`
(
    `id`          bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `ip`          varchar(255) DEFAULT NULL,
    `description` varchar(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_log`
(
    `id`        bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `logdate`   datetime            NOT NULL,
    `ip`        varchar(40)                                                                                                                                                                                                                                                                                                                                                                         DEFAULT NULL,
    `url`       varchar(10240)                                                                                                                                                                                                                                                                                                                                                                      DEFAULT NULL,
    `reason`    enum ('other', 'admindir', 'awayschedule', 'adminpw','ipwl','ipbl','sqlishield','antispam','tpone','tmpl','template','muashield','csrfshield','badbehaviour','geoblocking','rfishield','dfishield','uploadshield','xssshield','httpbl','loginfailure','securitycode', 'sessionshield', 'external', 'nonewadmins', 'nonewfrontendadmins', 'configmonitor', 'phpshield', '404shield') DEFAULT 'other',
    `extradata` mediumtext,
    PRIMARY KEY (`id`),
    KEY `#__admintools_log_logdate_reason` (`logdate`, `reason`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_redirects`
(
    `id`               bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `source`           varchar(255)                 DEFAULT NULL,
    `dest`             varchar(255)                 DEFAULT NULL,
    `ordering`         bigint(20)          NOT NULL DEFAULT '0',
    `published`        tinyint(1)          NOT NULL DEFAULT '1',
    `created`          datetime            NULL     DEFAULT NULL,
    `created_by`       int(11)             NOT NULL DEFAULT '0',
    `modified`         datetime            NULL     DEFAULT NULL,
    `modified_by`      int(11)             NOT NULL DEFAULT '0',
    `checked_out`      int(11)             NOT NULL DEFAULT '0',
    `checked_out_time` datetime            NULL     DEFAULT NULL,
    `keepurlparams`    tinyint(1)          NOT NULL DEFAULT '1',
    PRIMARY KEY (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_scanalerts`
(
    `id`           bigint(20)    NOT NULL AUTO_INCREMENT,
    `path`         varchar(2048) NOT NULL,
    `scan_id`      bigint(20)    NOT NULL DEFAULT '0',
    `diff`         mediumtext,
    `threat_score` int(11)       NOT NULL DEFAULT '0',
    `acknowledged` tinyint(4)    NOT NULL DEFAULT '0',
    PRIMARY KEY (`admintools_scanalert_id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_scans`
(
    `id`         bigint(20) unsigned            NOT NULL AUTO_INCREMENT,
    `comment`    longtext,
    `scanstart`  TIMESTAMP                      NULL     DEFAULT NULL,
    `scanend`    TIMESTAMP                      NULL     DEFAULT NULL,
    `status`     enum ('run','fail','complete') NOT NULL DEFAULT 'run',
    `origin`     varchar(30)                    NOT NULL DEFAULT 'backend',
    `totalfiles` int(11)                        NOT NULL DEFAULT '0',
    PRIMARY KEY (`id`),
    KEY `idx_stale` (`status`, `origin`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_storage`
(
    `key`   varchar(255) NOT NULL,
    `value` longtext     NOT NULL,
    PRIMARY KEY (`key`(100))
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_wafexceptions`
(
    `id`     bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `option` varchar(255) DEFAULT NULL,
    `view`   varchar(255) DEFAULT NULL,
    `query`  varchar(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_wafblacklists`
(
    `id`            bigint(20) unsigned                NOT NULL AUTO_INCREMENT,
    `option`        varchar(255)                       NOT NULL,
    `view`          varchar(255)                       NOT NULL,
    `task`          varchar(255)                       NOT NULL,
    `query`         varchar(255)                       NOT NULL,
    `query_type`    varchar(1)                         NOT NULL,
    `query_content` varchar(255)                       NOT NULL,
    `verb`          varchar(6)                         NOT NULL,
    `application`   enum ('site','admin','api','both') NOT NULL DEFAULT 'site',
    `enabled`       TINYINT(3)                         NOT NULL DEFAULT 1,
    PRIMARY KEY (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_waftemplates`
(
    `id`            bigint(20) unsigned                      NOT NULL AUTO_INCREMENT,
    `reason`        varchar(255)                             NOT NULL,
    `language`      varchar(10)                              NOT NULL DEFAULT '*',
    `subject`       varchar(255)                             NOT NULL,
    `template`      text                                     NOT NULL,
    `enabled`       TINYINT(3)                               NOT NULL DEFAULT 1,
    `email_num`     tinyint(3) unsigned                      NOT NULL,
    `email_numfreq` tinyint(3) unsigned                      NOT NULL,
    `email_freq`    enum ('','second','minute','hour','day') NOT NULL DEFAULT '',
    `created`       datetime                                 NULL     DEFAULT NULL,
    `created_by`    bigint(20)                               NOT NULL DEFAULT '0',
    `modified`      datetime                                 NULL     DEFAULT NULL,
    `modified_by`   bigint(20)                               NOT NULL DEFAULT '0',
    PRIMARY KEY (`admintools_waftemplate_id`),
    UNIQUE KEY `#__admintools_waftemplate_keylang` (`reason`(100), `language`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_ipautobanhistory`
(
    `id`     bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `ip`     varchar(255)        NOT NULL,
    `reason` varchar(255) DEFAULT 'other',
    `until`  datetime     DEFAULT NULL,
    PRIMARY KEY `id` (`id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_cookies`
(
    `series`      varchar(255) NOT NULL,
    `client_hash` varchar(255) NOT NULL,
    `valid_to`    datetime     NULL DEFAULT NULL,
    PRIMARY KEY (`series`(100))
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

CREATE TABLE `#__admintools_tempsupers`
(
    `user_id`    bigint(20) NOT NULL,
    `expiration` datetime   NOT NULL,
    PRIMARY KEY (`user_id`)
) ENGINE InnoDB
  DEFAULT CHARSET = utf8mb4
  DEFAULT COLLATE = utf8mb4_unicode_ci;

INSERT IGNORE INTO `#__admintools_wafblacklists`
(`option`, `view`, `task`, `query`, `query_type`, `query_content`, `verb`, `enabled`)
VALUES ('', '', '', 'list[select]', 'E', '!#^[\\p{L}\\d,\\s]+$#iu', '', 1);

INSERT IGNORE INTO `#__admintools_wafblacklists`
(`option`, `view`, `task`, `query`, `query_type`, `query_content`, `verb`, `enabled`)
VALUES ('com_users', '', '', 'user[groups]', 'P', '', '', 1);

INSERT IGNORE INTO `#__admintools_wafblacklists`
(`option`, `view`, `task`, `query`, `query_type`, `query_content`, `verb`, `application`, `enabled`)
VALUES ('com_content', 'category', '', 'type', 'R', '!#^[a-z][a-z\\-_0-9]{2,}$#i', '', 'site', 1);

/*
 * @package   admintools
 * @copyright Copyright (c)2010-2021 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

--
-- Create the common table for all Akeeba extensions.
--
-- This table is never uninstalled when uninstalling the extensions themselves.
--
CREATE TABLE IF NOT EXISTS `#__akeeba_common`
(
    `key`   VARCHAR(190) NOT NULL,
    `value` LONGTEXT     NOT NULL,
    PRIMARY KEY (`key`(100))
)
    ENGINE InnoDB
    DEFAULT COLLATE utf8_general_ci;